;; Generated package description from diff-hl.el  -*- no-byte-compile: t -*-
(define-package "diff-hl" "1.10.0" "Highlight uncommitted changes using VC" '((cl-lib "0.2") (emacs "25.1")) :commit "b80ff9b4a772f7ea000e86fbf88175104ddf9557" :authors '(("Dmitry Gutov" . "dmitry@gutov.dev")) :maintainer '("Dmitry Gutov" . "dmitry@gutov.dev") :keywords '("vc" "diff") :url "https://github.com/dgutov/diff-hl")
